@@ -2,7 +2,7 @@
  * This file is part of qdacco
  * qdacco: offline Dacco Catalan <-> English dictionary
  *
- * Copyright (c) 2005, 2006, 2007, 2008, 2009, 2011
+ * Copyright (c) 2005, 2006, 2007, 2008, 2009, 2011, 2013, 2015
  *      Carles Pina i Estany <carles@pina.cat>
  *
  * qdacco is free software; you can redistribute it and/or modify
@@ -24,15 +24,12 @@
 #include "AuxiliarGUI.h"
 #include "about.h"
 #include "configure.h"
-#include "connection.h"
-#include "suggeriment.h"
 #include "textbrowser.h"
 #include "trayicon.h"
 
-//qdaccolib
-#include <qdacco/auxiliar.h>
-#include <qdacco/StructureList.h>
+#include "nongui/StructureList.h"
 
+#include <QtCore/QChar>
 
 Main::Main(QWidget *)  //parent
 {
@@ -40,16 +37,11 @@ Main::Main(QWidget *)  //parent
 	ui.paraula->setParent(this);
 	ui.llistat->setParent(this);
 	ui.definicio->setFather(this);
-	ui.report->setText(tr("Report as new entry"));
 
 	resize(QSize(270,300));
 
-	ui.report->setEnabled(false);
-
 	installEventFilter(this);
 
-
-	//m_showList=0;
 	m_numberFound=0;
 
 	m_cat_eng = new QToolButton;
@@ -82,7 +74,6 @@ Main::Main(QWidget *)  //parent
 	connect(ui.paraula,SIGNAL(returnPressed()),this,SLOT(buscarEnter()));
 	connect(ui.helpAboutAction,SIGNAL(triggered()),this,SLOT(obrir_about()));
 
-	connect(ui.report,SIGNAL(clicked()),this,SLOT(obrir_suggeriment()));
 	connect(ui.llistat,SIGNAL(itemDoubleClicked(QListWidgetItem *)),this,SLOT(searchListWord(QListWidgetItem*)));
 	connect(ui.paraula,SIGNAL(textChanged(const QString &)),this,SLOT(paraulaChanged(const QString &)));
 
@@ -110,11 +101,11 @@ void Main::FestivalFinished(int exitStatus,QProcess::ExitStatus) {
 
 void Main::FestivalError(QProcess::ProcessError)
 {
-	showError(tr("Error executing Festival. Please consult the FAQ for help with this issue"));
+	showError(tr("Error executing Festival. Please check the FAQ for help with this issue"));
 }
 
 void Main::BrowserError(QProcess::ProcessError) {
-	showError(tr("Error executing browser. Please consult the FAQ for help with this issue"));
+	showError(tr("Error executing browser. Please check the FAQ for help with this issue"));
 }
 
 void Main::FestivalExecuteEntry() {
@@ -264,7 +255,7 @@ bool Main::eventFilter(QObject *, QEvent *event) //obj
 		moveDefinicio(event);
 	}
 
-	return TRUE;
+	return true;
 }
 
 void Main::buscarClicked()
@@ -274,9 +265,6 @@ void Main::buscarClicked()
 
 void Main::buscarEnter()
 {
-	ui.report->show();
-	ui.report->setEnabled(TRUE);
-
 	if (ui.llistat->isVisible()) {
 		QListWidgetItem *item;
 		item = ui.llistat->currentItem();
@@ -306,9 +294,7 @@ void Main::buscar()
 
 void Main::paraulaChanged(const QString &paraula)
 {
-	if (m_Autocomplete==FALSE) {
-		//ui.report->setEnabled(FALSE);
-		ui.report->hide();
+	if (m_Autocomplete==false) {
 		ui.actiu->hide();
 		return;
 	}
@@ -316,7 +302,6 @@ void Main::paraulaChanged(const QString &paraula)
 	bool enabled=false;
 
 	//Update the list
-	//ui.report->hide();
 	ui.actiu->hide();
 	ui.definicio->hide();
 	ui.llistat->clear();
@@ -330,23 +315,6 @@ void Main::paraulaChanged(const QString &paraula)
 	if (ui.llistat->count()>1 && ui.llistat->item(1)->text()==paraula) {
 		ui.llistat->setCurrentRow(1);
 	}
-
-	//Enable/disable the report button
-	if (paraula.length()==0) {
-		enabled=false;
-	}
-	else { //paraula.length>0
-		QListWidgetItem *item;
-		item = ui.llistat->item(0);
-		
-		enabled=true;
-		ui.report->setText(tr("Report as new entry"));
-
-		if (item!=NULL && item->text().compare(ui.paraula->text())==0) {
-			enabled=false;
-		}
-	}
-	ui.report->setEnabled(enabled);
 }
 
 int lib2class(QString q) { //bridge
@@ -402,7 +370,7 @@ void Main::UpdateList() {
 
 		QXmlInputSource source( &xmlFile );
 		QXmlSimpleReader reader;
-		reader.setFeature("http://trolltech.com/xml/features/report-whitespace-only-CharData",FALSE);   //if we don't use it, we get more entries because spaces...
+		reader.setFeature("http://trolltech.com/xml/features/report-whitespace-only-CharData",false);   //if we don't use it, we get more entries because spaces...
 		reader.setContentHandler(&handler);
 
 		handler.setParaula(search);
@@ -463,7 +431,7 @@ void Main::treballaBuscar() {
 
 			QXmlInputSource source( &xmlFile );
 			QXmlSimpleReader reader;
-			reader.setFeature("http://trolltech.com/xml/features/report-whitespace-only-CharData",FALSE);   //if we don't use it, we get more entries because spaces...
+			reader.setFeature("http://trolltech.com/xml/features/report-whitespace-only-CharData",false);   //if we don't use it, we get more entries because spaces...
 			reader.setContentHandler( &handler );
 
 			handler.setParaula(buscar_orig);
@@ -503,15 +471,8 @@ void Main::treballaBuscar() {
 				selectItem();
 				if (d.getNum()==0) {
 					showError(tr("Exact match not found"));
-					ui.report->setText(tr("Report as new entry"));
-					//ui.report->show();
 				}
 			}
-			if (d.getNum()>0) {
-				ui.report->setText(tr("Send comment(s)"));
-				ui.report->setEnabled(true);
-				//ui.report->show();
-			}
 			m_numberFound=d.getNum();
 		}
         }
@@ -530,7 +491,6 @@ void Main::posarApunt (int all) {
 
         ui.actiu->hide();
         ui.actiu->setText("");
-        //ui.report->hide();
         ui.paraula->selectAll();
         ui.paraula->setFocus();
 }
@@ -564,7 +524,7 @@ char Main::lletra_buscar(QString q) {
 
         a=q.at(0);
 
-        return (a.toAscii());
+        return (a.toLatin1());
 }
 
 void Main::selectItem()
@@ -667,12 +627,12 @@ void Main::posa_idioma() {
         posarApunt(0);
 
         if (m_idioma_actiu== Auxiliar::eng2cat() ) {
-                m_cat_eng->setChecked(TRUE);
-                m_eng_cat->setChecked(FALSE);
+                m_cat_eng->setChecked(true);
+                m_eng_cat->setChecked(false);
         }
         else {
-		m_eng_cat->setChecked(TRUE);
-                m_cat_eng->setChecked(FALSE);
+		m_eng_cat->setChecked(true);
+                m_cat_eng->setChecked(false);
         }
 }
 
@@ -714,69 +674,6 @@ void Main::select_word()
         ui.paraula->setFocus();
 }
 
-void Main::obrir_suggeriment()
-{
-	QSettings qs("dacco","qdacco");
-
-	QString name,email;
-	QString userWord,userTranslations,userExamples,userNotes;
-	int okay;
-
-	name = qs.value("/dacco/name","").toString();
-	email = qs.value("/dacco/email","").toString();
-
-	m_http = new HTTPConnection(this);
-
-	if (m_numberFound==0) {
-		m_http->sendNewWord(m_searched,name,email,m_idioma_actiu);
-		showMessage(tr("Sending..."));
-		//ui.report->hide();
-	}
-	else {
-        	Suggeriment *s = new Suggeriment;
-		s->setWord(ui.paraula->text());
-		s->exec();
-
-		s->getOkay(okay);
-
-		if (okay==1) {
-                        s->getUserWord(userWord);
-                        s->getUserTranslations(userTranslations);
-                        s->getUserExamples(userExamples);
-                        s->getUserNotes(userNotes);
-
-                        if (userTranslations.length()==0 &&
-                                userExamples.length()==0 &&
-                                userNotes.length()==0) {
-				showError(tr("You must type something"));
-                        }
-                        else {
-                                m_http->sendSuggestion(userWord,userTranslations,userExamples,userNotes,name,email,m_idioma_actiu);
-
-				showMessage(tr("Sending..."));
-                                //ui.report->hide();
-				ui.paraula->setFocus(Qt::OtherFocusReason);
-                        }
-                }
-                else {
-			showMessage(tr("Action cancelled"));
-			ui.paraula->setFocus(Qt::OtherFocusReason);
-                }
-	}
-}
-
-void Main::ReportChangeState(int,bool)
-{
-        if ((*m_http->getStateError()).compare("")==0) {
-		showMessage(tr("Correctly sent!"));
-        }
-        else {
-		showError(tr("Problem sending: ")+*m_http->getStateError());
-        }
-
-        delete m_http;
-}
-
 void Main::searchListWord(QListWidgetItem *a)
 {
 	ui.paraula->setText(a->text());
