@@ -2,7 +2,7 @@
  * This file is part of qdacco
  * qdacco: offline Dacco Catalan <-> English dictionary
  *
- * Copyright (c) 2005, 2006, 2007, 2009
+ * Copyright (c) 2005, 2006, 2007, 2009, 2015
  *      Carles Pina i Estany <carles@pina.cat>
  *
  * qdacco is free software; you can redistribute it and/or modify
@@ -23,9 +23,10 @@
 #define MYLISTWIDGET_H
 
 #include <QtGui>
+#include <QtWidgets/QListWidget>
 
 //qdaccolib
-#include <qdacco/auxiliar.h>
+#include <nongui/auxiliar.h>
 
 class MyListWidget: public QListWidget
 {
