@@ -57,7 +57,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <location filename="about.ui" line="180"/>
-        <source>Carles Pina i Estany, 2005, 2006, 2007, 2008, 2009, 2011</source>
+        <source>Carles Pina i Estany, 2005, 2006, 2007, 2008, 2009, 2011, 2013</source>
         <translation></translation>
     </message>
     <message>
@@ -99,7 +99,7 @@ Dades llicenciades amb LGPL.</translation>
     </message>
     <message>
         <location filename="about.cpp" line="27"/>
-        <source>qdacco version: </source>
+        <source>qdacco version:</source>
         <translation>versió qdacco:</translation>
     </message>
 </context>
